@@ -7,19 +7,18 @@ from fiotclient import utils
 from fiotclient.config import FiwareConfig
 
 
-def _log_request_url(method: str, url: str, params: dict):
+def _log_request_url(method: str, url: str, params: dict, headers: dict):
     params_str = '&'.join(map(lambda key: f'{key}={params[key]}', params.keys())) if params else ''
     if params_str:
-        logging.info(f"{method} {url}?{params_str}")
+        logging.info(f"{method} {url}?{params_str} {headers}")
     else:
-        logging.info(f"{method} {url}")
+        logging.info(f"{method} {url} {headers}")
 
 
 def _log_request(method, url, params, headers, str_payload):
-    _log_request_url(method, url, params)
-    logging.debug(f"Headers: {headers}")
+    _log_request_url(method, url, params, headers)
     if str_payload != '':
-        logging.debug(f"Payload: {str_payload}")
+        logging.info(f"Request payload: {str_payload}")
 
 
 def _log_response(status_code, response):
